==> blueprint-component-mapper-3.2.0.tgz: package/esm/checkbox/checkbox.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React, { useContext } from 'react';
import PropTypes from 'prop-types';
import MultipleChoiceList from '@data-driven-forms/common/multiple-choice-list';
import { Checkbox } from "@blueprintjs/core/lib/esm/components/forms/controls.js";
import { FormGroup } from "@blueprintjs/core/lib/esm/components/forms/formGroup.js";
import { Intent } from "@blueprintjs/core/lib/esm/common/intent.js";
import FormGroupWrapper from '../form-group/form-group';
import propsCatcher from '../props-catcher/props-catcher';
import BlueprintContext from '../blueprint-context/blueprint-context';

var SingleCheckbox = function SingleCheckbox(_ref) {
  var input = _ref.input,
      isDisabled = _ref.isDisabled,
      disabled = _ref.disabled,
      label = _ref.label,
      providerRequired = _ref.providerRequired,
      props = _objectWithoutProperties(_ref, ["input", "isDisabled", "disabled", "label", "providerRequired"]);

  return /*#__PURE__*/React.createElement(Checkbox, _extends({
    label: label
  }, propsCatcher(props), props.isRequired && {
    label: /*#__PURE__*/React.createElement("span", null, label, " ", providerRequired)
  }, {
    disabled: disabled || isDisabled
  }, input));
};

SingleCheckbox.propTypes = {
  input: PropTypes.object,
  isDisabled: PropTypes.bool,
  label: PropTypes.node,
  isRequired: PropTypes.bool,
  providerRequired: PropTypes.node,
  disabled: PropTypes.bool
};

var Wrapper = function Wrapper(_ref2) {
  var children = _ref2.children,
      isRequired = _ref2.isRequired,
      showError = _ref2.showError,
      error = _ref2.error,
      validateOnMount = _ref2.validateOnMount,
      props = _objectWithoutProperties(_ref2, ["children", "isRequired", "showError", "error", "validateOnMount"]);

  var _useContext = useContext(BlueprintContext),
      required = _useContext.required;

  return /*#__PURE__*/React.createElement(FormGroup, _extends({}, props, isRequired && {
    labelInfo: required
  }, error && (showError || validateOnMount) && {
    helperText: error,
    intent: Intent.DANGER
  }), children);
};

Wrapper.propTypes = {
  children: PropTypes.node,
  isRequired: PropTypes.bool,
  showError: PropTypes.bool,
  error: PropTypes.string,
  validateOnMount: PropTypes.bool
};

var WrapperCheckbox = function WrapperCheckbox(props) {
  return props.options ? /*#__PURE__*/React.createElement(MultipleChoiceList, _extends({}, props, {
    Wrapper: Wrapper,
    Checkbox: SingleCheckbox
  })) : /*#__PURE__*/React.createElement(FormGroupWrapper, _extends({}, props, {
    hideLabel: true,
    Component: SingleCheckbox
  }));
};

WrapperCheckbox.propTypes = {
  options: PropTypes.array
};
export default WrapperCheckbox;

==> blueprint-component-mapper-3.16.11.tgz: package/esm/checkbox/checkbox.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["input", "isDisabled", "disabled", "label", "providerRequired"],
    _excluded2 = ["children", "isRequired", "showError", "error", "validateOnMount"];
import React, { useContext } from 'react';
import PropTypes from 'prop-types';
import MultipleChoiceList from '@data-driven-forms/common/multiple-choice-list';
import { Checkbox } from "@blueprintjs/core/lib/esm/components/forms/controls.js";
import { FormGroup } from "@blueprintjs/core/lib/esm/components/forms/formGroup.js";
import { Intent } from "@blueprintjs/core/lib/esm/common/intent.js";
import FormGroupWrapper from '../form-group/form-group';
import propsCatcher from '../props-catcher/props-catcher';
import BlueprintContext from '../blueprint-context/blueprint-context';

var SingleCheckbox = function SingleCheckbox(_ref) {
  var input = _ref.input,
      isDisabled = _ref.isDisabled,
      disabled = _ref.disabled,
      label = _ref.label,
      providerRequired = _ref.providerRequired,
      props = _objectWithoutProperties(_ref, _excluded);

  return /*#__PURE__*/React.createElement(Checkbox, _extends({
    label: label
  }, propsCatcher(props), props.isRequired && {
    label: /*#__PURE__*/React.createElement("span", null, label, " ", providerRequired)
  }, {
    disabled: disabled || isDisabled
  }, input));
};

SingleCheckbox.propTypes = {
  input: PropTypes.object,
  isDisabled: PropTypes.bool,
  label: PropTypes.node,
  isRequired: PropTypes.bool,
  providerRequired: PropTypes.node,
  disabled: PropTypes.bool
};

var Wrapper = function Wrapper(_ref2) {
  var children = _ref2.children,
      isRequired = _ref2.isRequired,
      showError = _ref2.showError,
      error = _ref2.error,
      validateOnMount = _ref2.validateOnMount,
      props = _objectWithoutProperties(_ref2, _excluded2);

  var _useContext = useContext(BlueprintContext),
      required = _useContext.required;

  return /*#__PURE__*/React.createElement(FormGroup, _extends({}, props, isRequired && {
    labelInfo: required
  }, error && (showError || validateOnMount) && {
    helperText: error,
    intent: Intent.DANGER
  }), children);
};

Wrapper.propTypes = {
  children: PropTypes.node,
  isRequired: PropTypes.bool,
  showError: PropTypes.bool,
  error: PropTypes.string,
  validateOnMount: PropTypes.bool
};

var WrapperCheckbox = function WrapperCheckbox(props) {
  return props.options ? /*#__PURE__*/React.createElement(MultipleChoiceList, _extends({}, props, {
    Wrapper: Wrapper,
    Checkbox: SingleCheckbox
  })) : /*#__PURE__*/React.createElement(FormGroupWrapper, _extends({}, props, {
    hideLabel: true,
    Component: SingleCheckbox
  }));
};

WrapperCheckbox.propTypes = {
  options: PropTypes.array
};
export default WrapperCheckbox;
